@@ -88,6 +88,6 @@ multKM <-
       X <- t(apply(X,1,function(x) x/sum(x)*c[1]))
     }
     
-    return(as.data.frame(X))
+    return(as.data.frame(X,stringsAsFactors=TRUE))
   }  
     
\ No newline at end of file
